@@ -7,81 +7,24 @@ This example employs several unsupervised learning techniques to extract
 the stock market structure from variations in historical quotes.
 
 The quantity that we use is the daily variation in quote price: quotes
-that are linked tend to cofluctuate during a day.
-
-.. _stock_market:
-
-Learning a graph structure
---------------------------
-
-We use sparse inverse covariance estimation to find which quotes are
-correlated conditionally on the others. Specifically, sparse inverse
-covariance gives us a graph, that is a list of connection. For each
-symbol, the symbols that it is connected too are those useful to explain
-its fluctuations.
-
-Clustering
-----------
-
-We use clustering to group together quotes that behave similarly. Here,
-amongst the :ref:`various clustering techniques <clustering>` available
-in the scikit-learn, we use :ref:`affinity_propagation` as it does
-not enforce equal-size clusters, and it can choose automatically the
-number of clusters from the data.
-
-Note that this gives us a different indication than the graph, as the
-graph reflects conditional relations between variables, while the
-clustering reflects marginal properties: variables clustered together can
-be considered as having a similar impact at the level of the full stock
-market.
-
-Embedding in 2D space
----------------------
-
-For visualization purposes, we need to lay out the different symbols on a
-2D canvas. For this we use :ref:`manifold` techniques to retrieve 2D
-embedding.
-
-
-Visualization
--------------
-
-The output of the 3 models are combined in a 2D graph where nodes
-represents the stocks and edges the:
-
-- cluster labels are used to define the color of the nodes
-- the sparse covariance model is used to display the strength of the edges
-- the 2D embedding is used to position the nodes in the plan
-
-This example has a fair amount of visualization-related code, as
-visualization is crucial here to display the graph. One of the challenge
-is to position the labels minimizing overlap. For this we use an
-heuristic based on the direction of the nearest neighbor along each
-axis.
-
+that are linked tend to fluctuate in relation to each other during a day.
 """
 
 # Author: Gael Varoquaux gael.varoquaux@normalesup.org
 # License: BSD 3 clause
 
-import sys
-
-import numpy as np
-import matplotlib.pyplot as plt
-from matplotlib.collections import LineCollection
-
-import pandas as pd
-
-from sklearn import cluster, covariance, manifold
-
-
-# #############################################################################
+# %%
 # Retrieve the data from Internet
-
+# -------------------------------
+#
 # The data is from 2003 - 2008. This is reasonably calm: (not too long ago so
 # that we get high-tech firms, and before the 2008 crash). This kind of
-# historical data can be obtained for from APIs like the quandl.com and
-# alphavantage.co ones.
+# historical data can be obtained from APIs like the quandl.com and
+# alphavantage.co .
+
+import sys
+import numpy as np
+import pandas as pd
 
 symbol_dict = {
     "TOT": "Total",
@@ -158,50 +101,104 @@ for symbol in symbols:
 close_prices = np.vstack([q["close"] for q in quotes])
 open_prices = np.vstack([q["open"] for q in quotes])
 
-# The daily variations of the quotes are what carry most information
+# The daily variations of the quotes are what carry the most information
 variation = close_prices - open_prices
 
+# %%
+# .. _stock_market:
+#
+# Learning a graph structure
+# --------------------------
+#
+# We use sparse inverse covariance estimation to find which quotes are
+# correlated conditionally on the others. Specifically, sparse inverse
+# covariance gives us a graph, that is a list of connection. For each
+# symbol, the symbols that it is connected too are those useful to explain
+# its fluctuations.
 
-# #############################################################################
-# Learn a graphical structure from the correlations
-edge_model = covariance.GraphicalLassoCV()
+from sklearn import covariance
+
+alphas = np.logspace(-1.5, 1, num=10)
+edge_model = covariance.GraphicalLassoCV(alphas=alphas)
 
 # standardize the time series: using correlations rather than covariance
-# is more efficient for structure recovery
+# former is more efficient for structure recovery
 X = variation.copy().T
 X /= X.std(axis=0)
 edge_model.fit(X)
 
-# #############################################################################
-# Cluster using affinity propagation
+# %%
+# Clustering using affinity propagation
+# -------------------------------------
+#
+# We use clustering to group together quotes that behave similarly. Here,
+# amongst the :ref:`various clustering techniques <clustering>` available
+# in the scikit-learn, we use :ref:`affinity_propagation` as it does
+# not enforce equal-size clusters, and it can choose automatically the
+# number of clusters from the data.
+#
+# Note that this gives us a different indication than the graph, as the
+# graph reflects conditional relations between variables, while the
+# clustering reflects marginal properties: variables clustered together can
+# be considered as having a similar impact at the level of the full stock
+# market.
+
+from sklearn import cluster
 
 _, labels = cluster.affinity_propagation(edge_model.covariance_, random_state=0)
 n_labels = labels.max()
 
 for i in range(n_labels + 1):
-    print("Cluster %i: %s" % ((i + 1), ", ".join(names[labels == i])))
+    print(f"Cluster {i + 1}: {', '.join(names[labels == i])}")
 
-# #############################################################################
-# Find a low-dimension embedding for visualization: find the best position of
+# %%
+# Embedding in 2D space
+# ---------------------
+#
+# For visualization purposes, we need to lay out the different symbols on a
+# 2D canvas. For this we use :ref:`manifold` techniques to retrieve 2D
+# embedding.
+# We use a dense eigen_solver to achieve reproducibility (arpack is initiated
+# with the random vectors that we don't control). In addition, we use a large
+# number of neighbors to capture the large-scale structure.
+
+# Finding a low-dimension embedding for visualization: find the best position of
 # the nodes (the stocks) on a 2D plane
 
-# We use a dense eigen_solver to achieve reproducibility (arpack is
-# initiated with random vectors that we don't control). In addition, we
-# use a large number of neighbors to capture the large-scale structure.
+from sklearn import manifold
+
 node_position_model = manifold.LocallyLinearEmbedding(
     n_components=2, eigen_solver="dense", n_neighbors=6
 )
 
 embedding = node_position_model.fit_transform(X.T).T
 
-# #############################################################################
+# %%
 # Visualization
+# -------------
+#
+# The output of the 3 models are combined in a 2D graph where nodes
+# represents the stocks and edges the:
+#
+# - cluster labels are used to define the color of the nodes
+# - the sparse covariance model is used to display the strength of the edges
+# - the 2D embedding is used to position the nodes in the plan
+#
+# This example has a fair amount of visualization-related code, as
+# visualization is crucial here to display the graph. One of the challenge
+# is to position the labels minimizing overlap. For this we use an
+# heuristic based on the direction of the nearest neighbor along each
+# axis.
+
+import matplotlib.pyplot as plt
+from matplotlib.collections import LineCollection
+
 plt.figure(1, facecolor="w", figsize=(10, 8))
 plt.clf()
 ax = plt.axes([0.0, 0.0, 1.0, 1.0])
 plt.axis("off")
 
-# Display a graph of the partial correlations
+# Plot the graph of partial correlations
 partial_correlations = edge_model.precision_.copy()
 d = 1 / np.sqrt(np.diag(partial_correlations))
 partial_correlations *= d
@@ -210,7 +207,7 @@ non_zero = np.abs(np.triu(partial_correlations, k=1)) > 0.02
 
 # Plot the nodes using the coordinates of our embedding
 plt.scatter(
-    embedding[0], embedding[1], s=100 * d ** 2, c=labels, cmap=plt.cm.nipy_spectral
+    embedding[0], embedding[1], s=100 * d**2, c=labels, cmap=plt.cm.nipy_spectral
 )
 
 # Plot the edges
